#!/bin/sh

set -e
. ./testsuite/common.sh

testpkg='testsuite/data/pearpkg1'

expect_equal "_pkgtools --sourcedirectory '${testpkg}' phppear description" '<Some random notes>
    This is a paragraph.

    Those are bullets:
    * Number one
    * Number two
 '
