#!/bin/sh

set -e
. ./testsuite/common.sh

composerpkg='testsuite/data/composerpkg2'

expect_equal "bin/phpabtpl '${composerpkg}/composer.json'" "<?php

// Require
require_once '/usr/share/php/Proj1/AliasDevMaster/autoload.php';
require_once '/usr/share/php/Proj1/AliasInline/autoload.php';
require_once '/usr/share/php/Proj1/Caret/autoload.php';
require_once '/usr/share/php/Proj1/CaretPre10/autoload.php';
require_once '/usr/share/php/Proj1/EqualAny/autoload.php';
require_once '/usr/share/php/Proj1/EqualExact/autoload.php';
require_once '/usr/share/php/Proj1/EqualSelf/autoload.php';
require_once '/usr/share/php/Proj1/EqualWildcard/autoload.php';
require_once '/usr/share/php/Proj1/RangeGe/autoload.php';
require_once '/usr/share/php/Proj1/RangeGeLt/autoload.php';
require_once '/usr/share/php/Proj1/RangeGtLe/autoload.php';
require_once '/usr/share/php/Proj1/RangeNoComma/autoload.php';
require_once '/usr/share/php/Proj1/StabilityBeta/autoload.php';
require_once '/usr/share/php/Proj1/StabilityDev/autoload.php';
require_once '/usr/share/php/Proj1/StabilityPatch/autoload.php';
require_once '/usr/share/php/Proj1/StabilityflagAlphaCaps/autoload.php';
require_once '/usr/share/php/Proj1/StabilityflagBeta/autoload.php';
require_once '/usr/share/php/Proj1/StabilityflagDev/autoload.php';
require_once '/usr/share/php/Proj1/Tilde/autoload.php';
require_once '/usr/share/php/Proj1/TildeMajor/autoload.php';
require_once '/usr/share/php/Proj1/UnderscoreCAPSDot/autoload.php';
require_once '/usr/share/php/Proj1/UnsupportedOr/autoload.php';
require_once '/usr/share/php/Proj2/RangeNoComma/autoload.php';

// Suggest
if (stream_resolve_include_path('/usr/share/php/Proj1/SuggestUnparsable/autoload.php')) { include_once '/usr/share/php/Proj1/SuggestUnparsable/autoload.php'; }
if (stream_resolve_include_path('/usr/share/php/Proj1/SuggestVersioned/autoload.php')) { include_once '/usr/share/php/Proj1/SuggestVersioned/autoload.php'; }

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function(\$class) {
        static \$classes = null;
        if (\$classes === null) {
            \$classes = array(
                ___CLASSLIST___
            );
        }
        \$cn = strtolower(\$class);
        if (isset(\$classes[\$cn])) {
            require ___BASEDIR___\$classes[\$cn];
        }
    },
    ___EXCEPTION___,
    ___PREPEND___
);
// @codeCoverageIgnoreEnd

// Files"
